using Cloud.Models;
using Cloud.Services.Broker.Support;

namespace Cloud.Services.Domain;

public interface IGreenhouseService
{
    /// <summary>
    /// Возвращает текущую информацию о конкретной теплице из брокера
    /// </summary>
    /// <param name="id">ID теплицы</param>
    /// <param name="farmId">ID фермы, то есть брокера</param>
    /// <returns>Текущие данные о теплице от менеджера теплицы</returns>
    public Task<GreenhouseInfo?> GetGreenhouseInfo(int id, int farmId);
    /// <summary>
    /// Возвращает сохраненные данные для автоматизации теплицы из базы данных
    /// </summary>
    /// <param name="id">ID теплицы</param>
    /// <returns>Данные для автоматизации теплицы</returns>
    public Task<Greenhouse?> GetGreenhouse(int id);
    /// <summary>
    /// Возвращает список данных о всех теплицах пользователя из брокера
    /// </summary>
    /// <param name="farmId">ID фермы</param>
    /// <returns>Список текущих данных о теплицах</returns>
    public Task<IEnumerable<GreenhouseInfo>?> GetAll(int farmId);
    /// <summary>
    /// Сохраняет данные об автоматизации теплицы в базу данных
    /// </summary>
    /// <param name="greenhouse">Данные автоматизации теплицы</param>
    /// <returns>Созданную сущность из базы данных</returns>
    public Task<Greenhouse> Create(Greenhouse greenhouse);
    /// <summary>
    /// Обновляет данные автоматизации теплицы в базе данных
    /// </summary>
    /// <param name="greenhouse">Новая информация об автоматизации теплицы</param>
    /// <returns>Обновленную сущность из базы данных</returns>
    public Task<Greenhouse> Update(Greenhouse greenhouse);
    /// <summary>
    /// Удаляет данные об автоматизации теплицы из базы данных
    /// </summary>
    /// <param name="id">ID данных автоматизации теплицы</param>
    /// <returns>Возвращает удаленную сущность</returns>
    public Task<Greenhouse> Delete(int id);
}