import axios, { AxiosError, AxiosRequestHeaders } from 'axios';
import IUser from '../models/IUser';
import IFarm from '../models/IFarm';
import LoginRequest from '../Requests/LoginRequest';
import IRegisterRequest from '../Requests/RegisterRequest';

const API_BASE_URL = 'http://localhost:5124/api';

const getHeaders = (): { [key: string]: string } => {
  return {
    'Content-Type': 'application/json',
  };
};
export const getFarms = async (): Promise<IFarm[]> => {
  try {
    const response = await axios.get(`${API_BASE_URL}/farms`, { headers: getHeaders() });
    return response.data;
  } catch (error: unknown) {
    const axiosError = error as AxiosError;
    console.error('Error fetching farms:', axiosError.message);
    throw error;
  }
};

export const getUser = async (userId: number): Promise<IUser> => {
  try {
    const response = await axios.get(`${API_BASE_URL}/Auth/user/${userId}`, { headers: getHeaders() });
    return response.data;
  } catch (error: unknown) {
    const axiosError = error as AxiosError;
    console.error('Error fetching user:', axiosError.message);
    throw error;
  }
};

export const createUser = async (userData: IRegisterRequest): Promise<IUser> => {
  try {
    const response = await axios.post(`${API_BASE_URL}/Auth/register`, userData, { headers: getHeaders() });
    return response.data;
  } catch (error: unknown) {
    const axiosError = error as AxiosError;
    console.error('Error creating user:', axiosError.message);
    if (axiosError.response) {
      // Логируем дополнительные данные об ошибке
      console.error('Response data:', axiosError.response.data);
      console.error('Response status:', axiosError.response.status);
    }
    throw error;
  }
};


export const loginUser = async (userData: LoginRequest): Promise<string> => {
  try {
    const response = await axios.post(`${API_BASE_URL}/Auth/login`, userData, { headers: getHeaders() });
    return response.data; // JWT токен
  } catch (error: unknown) {
    const axiosError = error as AxiosError;
    console.error('Error logging in:', axiosError.message);
    throw error;
  }
};