import React, { useState, useEffect } from 'react';
import { DatePicker, Select, Button, Form } from 'antd';
import { useParams } from 'react-router-dom';
import { Line } from 'react-chartjs-2';

import {
    Chart as ChartJS,
    CategoryScale,
    LinearScale,
    BarElement,
    Title,
    Tooltip,
    Legend,
    ArcElement,
    PointElement,
    LineElement,
  } from 'chart.js';

import GreenhouseService from '../../core/services/greenhouse-service';
import { setLabels } from 'react-chartjs-2/dist/utils';


export function GreenHouseStats() {
    const { id } = useParams<{ id: string }>();
    const [from, setFrom] = useState<Date | null>(null);
    const [to, setTo] = useState<Date | null>(null);
    const [type, setType] = useState<'humidity' | 'temperature'>('humidity');

    const service = new GreenhouseService();
    
    const temperatureHistory = service.getTemperatureHistory(1);
    const humidityHistory = service.getHumidityHistory(1);
    
    const isButtonDisabled = !from || !to || (to.valueOf() === undefined || from.valueOf() === undefined)

    //const isButtonDisabled = !from || !to || (to.getTime() - from.getTime()) / (1000 * 60 * 60 * 24) > 30;
    ChartJS.register(ArcElement, CategoryScale, LinearScale, PointElement, LineElement, Title, Tooltip, Legend);

const [chartData, setChartData] = useState({
    labels: [],
    datasets: [
        {
            label: '',
            data: [],
            borderColor: '',
            fill: false,
            tension: 0.4,
        },
    ],
});


    const [data, setData] = useState({
        labels: ["Jan", "Feb", "Mar", "Apr", "May"],
                datasets: [
                  {
                    label: "Up Line",
                    data: [10, 20, 15, 40, 30],
                    borderColor: "rgb(28, 44, 44)", // Customize line color
                    fill: false,
                    tension: 0.4, // Adjust line tension for smoother curves
                  },

                ],
    });

    useEffect(() => {
        
    }, [from, to, type]);

    const createDateRange = (startDate: string, endDate: string) => {
        const start = new Date(startDate);
        const end = new Date(endDate);
        const dates = [];
        let currentDate = start;
        while (currentDate <= end) {
            dates.push(new Date(currentDate));
            currentDate.setDate(currentDate.getDate() + 1);
        }
        return dates;
    };

    const handleGenerateReport = () => {
        console.log(from, to, type);

        if (from && to) {
            const startDate = '2024-12-14';
            const endDate = '2024-12-24';

            const itemdata = type === 'humidity' ? humidityHistory : temperatureHistory;
            const startDateObj = new Date(Date.parse(startDate));
            const endDateObj = new Date(Date.parse(endDate));

            const filteredData = itemdata.filter(item => {
                const itemDate = new Date(Date.parse(item.date));
                return itemDate >= startDateObj && itemDate <= endDateObj;
            });

            filteredData.forEach(element => {
                console.log('wff');
                console.log(element.value);
            });

            const dateRange = createDateRange(startDate, endDate);
            const labels: string[] = dateRange.map(date => date.getDate() % 5 === 0 ? date.toLocaleDateString('ru-RU', { day: 'numeric', month: 'long' }) : '');

            setChartData({
                labels,
                datasets: [
                    {
                        label: type === 'humidity' ? 'Влажность' : 'Температура',
                        data: itemdata.map(item => item.value),
                        backgroundColor: [
                            'rgb(153, 102, 255)'
                        ],
                        borderColor: [
                            'rgb(153, 102, 255)'
                        ],
                        borderWidth: 1
                    }
                ]
            } as any);

            // setData({
            //     labels,
            //     datasets: [
            //         {
            //             label: 'Expenses by Month',
            //             data: filteredData.map(item => item.value),
            //             backgroundColor: [
            //                 'rgb(153, 102, 255)'
            //             ],
            //             borderColor: [
            //                 'rgb(153, 102, 255)'
            //             ],
            //             borderWidth: 1
            //         }
            //     ]
            // } as any);

        }
    };


    const options = {
        scales: {
          x: {
            display: true,
            title: {
              display: true,
              text: "Дата",
            },
            min: 0,
            max: 100,
          },
          y: {
            display: true,
            title: {
              display: true,
              text: "Значение",
            },
          },
        },
      };
    return (
        <Form onFinish={handleGenerateReport} className="p-8" style={{ marginTop: '100px', marginLeft: '650px', height: '800px', width: '600px' }}>
            <h1 className="text-2xl font-bold mb-4">Статистика по выбранной теплице</h1>
            <div className="grid grid-cols-2 gap-4">
                <DatePicker value={from} onChange={(date) => setFrom(date)} format="DD.MM.YYYY" />
                <DatePicker value={to} onChange={(date) => setTo(date)} format="DD.MM.YYYY" />
            </div>
            <div className="m-4">
                <Select value={type} onChange={(value) => setType(value)}>
                    <Select.Option value="humidity">Влажность</Select.Option>
                    <Select.Option value="temperature">Температура</Select.Option>
                </Select>
            </div>
            <Button type="primary" htmlType="submit" disabled={isButtonDisabled}>
                Сформировать отчёт
            </Button>
            <div className="m-4">
                <Line data={chartData} options={options} />
            </div>
        </Form>
  );
};

