import { useState } from 'react';
import GreenhouseService, { HistoryData } from '../core/services/greenhouse-service';
import { Greenhouse, GreenhouseInfo, HeatingMode, WateringMode } from '../core/api/data-contracts';
import { Link, useNavigate, useParams } from 'react-router-dom';
import GreenhouseDataDisplay from '../components/greenhouse/GreenhouseDataDisplay';
import GreenhouseSettingsForm from '../components/greenhouse/GreenhouseSettingsForm';
import GreenhouseManager from '../components/greenhouse/GreenhouseManager';
import GreenhouseCommandHistoryTable from '../components/greenhouse/GreenhouseCommandTable';
import { Button } from 'antd';

const GreenHousePage = () => {
    const { id } = useParams();
    let service = new GreenhouseService();
    
    const [info, setInfo] = useState<GreenhouseInfo>(service.getData(Number(id!)));
    const [history, setHistory] = useState<HistoryData[]>(service.getCommandsHistory(Number(id!)));
    

    const updateSettings = (settings: Greenhouse) => {
        const success = service.setSettings(settings);
        if (success) {
            alert('Настройки успешно обновлены');
        } else {
            alert('Ошибка обновления настроек');
        }
    };

    return (
            <div style={{ display: 'flex', flexDirection: 'column'}}>
                <Button type='primary' className='m-2'>
                    <Link to={'/greenhouses/' + id + '/statistics'}>Получить статистику по данной теплице</Link>
                </Button>
                <div style={{ display: 'flex', flexDirection: 'row'}}>
                    <GreenhouseDataDisplay info={info} />
                    <GreenhouseManager />
                    <GreenhouseSettingsForm updateSettings={updateSettings} id={info.id!} />
                </div>
                <GreenhouseCommandHistoryTable history={history} className="m-3" />
            </div>
    );
}

export default GreenHousePage;