import React, { useState } from 'react';
import { Link, useNavigate } from 'react-router-dom';
import { Button, Form, Input } from 'antd';
import { loginUser } from '../API/api';
import ILoginRequest from '../Requests/LoginRequest';
import Text from 'antd/es/typography/Text';

export function LoginPage () {
  const [email, setEmail] = useState('');
  const [password, setPassword] = useState('');
  const navigate = useNavigate();

  const onFinish = async () => {
    // Создаём объект с данными для отправки на сервер
    const userData: ILoginRequest = {
      email,
      password,
    };

    try {
      const token = await loginUser(userData);
      // Сохраняем токен
      localStorage.setItem('token', token);
      alert('Вы успешно вошли в систему!');
      navigate('/'); // Перенаправляем на главную страницу
    } catch (error) {
      console.error('Error logging in:', error);
      alert('Ошибка при входе в систему. Проверьте введенные данные.');
    }
  };

  return (
    <div className="container mx-auto" style={{ maxWidth: '20%', marginTop: '200px'}}>
      <Text style={{ fontSize: '24px', fontWeight: 'bold', marginBottom: '40px', marginTop: '20px'}}>Вход в систему</Text>
      <Form onFinish={onFinish}>
        <Form.Item 
          label="Email" 
          name="email" 
          rules={[{ required: true, type: 'email', message: 'Пожалуйста, введите корректный email!' }]}
        >
          <Input value={email} onChange={e => setEmail(e.target.value)} />
        </Form.Item>
        <Form.Item 
          label="Пароль" 
          name="password" 
          rules={[{ required: true, min: 8, message: 'Пароль должен содержать не менее 8 символов!' }]}
        >
          <Input
            type="password"
            value={password}
            onChange={e => setPassword(e.target.value)}
          />
        </Form.Item>
        <Form.Item>
          <Button type="primary" htmlType="submit">
            Войти
          </Button>
        </Form.Item>
        <p>
          Нет аккаунта? <Link to="/register">Зарегистрируйтесь</Link>
        </p>
      </Form>
    </div>
  );
};

export default LoginPage;
